import 'package:flutter/cupertino.dart';
import 'package:go_router/go_router.dart';
import 'package:starting_template/core/enums/page_protection.dart';
import 'package:starting_template/core/extensions/go_route_extension.dart';
import 'package:starting_template/core/routes/go_router_refresh_stream.dart';
import 'package:starting_template/presentation/features/home/home.dart';

abstract class AppRouter {
  /// Default transition for all pages
  static Page<void> defaultTransition(
    BuildContext context,
    GoRouterState state,
    Widget child,
  ) =>
      CupertinoPage<void>(key: state.pageKey, child: child);

  /// Disable transition animation
  static Page<void> noTransition(
    BuildContext context,
    GoRouterState state,
    Widget child,
  ) =>
      NoTransitionPage(key: state.pageKey, child: child);

  /// Defines GoRoute routes.
  static final List<GoRoute> routes = [
    GoRoute(
      path: '/',
      name: Home.pageName,
      pageBuilder: (context, state) =>
          defaultTransition(context, state, const Home()),
    )..setPublic(),
  ];

  /// Router
  static GoRouter routerOf(BuildContext context) => GoRouter(
        initialLocation: '/',
        routes: AppRouter.routes,
        debugLogDiagnostics: true,
        // TODO(wyatt): Add authentication logic
        redirect: (context, state) {
          /// Define the default guard
          /// This is the guard that will be used if the route
          /// does not have a guard set. (It is set to [PageProtection.none])
          const defaultGuard = PageProtection.protected;

          // Compute current route
          // Compute current route
          final currentRoute = AppRouter.routes.firstWhere(
            (route) => route.path == state.location,
          );

          // Get the guard of the current route
          final guard = currentRoute.guard;

          return null;
        },
        refreshListenable: GoRouterRefreshStream(const Stream.empty()),
      );
}
