// Copyright (C) 2023 WYATT GROUP
// Please see the AUTHORS file for details.
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program. If not, see <https://www.gnu.org/licenses/>.

import 'package:flutter/material.dart';
import 'package:{{#snakeCase}}{{project_name}}{{/snakeCase}}/core/flavors/flavor.dart';

/// {@template flavor_banner}
/// A banner that displays the current flavor.
/// This is useful for quickly identifying which flavor is currently running.
///
/// When [Flavor.shouldShowBanner] is `false`, this widget will return [child].
/// You can also override this behavior by setting [visible] to `true`.
///
/// Wrap your [MaterialApp] with this widget to display the banner.
///
/// Example:
///
/// ```dart
/// FlavorBanner(
///  visible: true, // or null to use Flavor.shouldShowBanner()
///  child: const MaterialApp(
///   title: 'Starting Template',
///   ...
///  ),
/// );
/// ```
/// {@endtemplate}
class FlavorBanner extends StatelessWidget {
  const FlavorBanner({
    this.child,
    this.visible,
    super.key,
  });

  final Widget? child;

  /// Defaults to [Flavor.shouldShowBanner].
  final bool? visible;

  @override
  Widget build(BuildContext context) {
    final visible = this.visible ?? Flavor.shouldShowBanner();

    if (!visible) {
      return child ?? const SizedBox.shrink();
    }

    final flavor = Flavor.instance;

    return Directionality(
      textDirection: TextDirection.ltr,
      child: Banner(
        location: BannerLocation.topEnd,
        message: flavor.name,
        color: flavor.color,
        child: child,
      ),
    );
  }
}
